@@ -53,7 +53,7 @@ client = TestClient(api)
 
 
 class TestThrottling:
-    def setup(self):
+    def setup_method(self):
         self.user = ThrottlingMockUser("Ninja")
         self.user.set_id(uuid.uuid4())
 
