@@ -33,7 +33,7 @@ client = TestClient(ThrottledController)
 
 
 class TestThrottledController:
-    def setup(self):
+    def setup_method(self):
         self.user = ThrottlingMockUser("Ninja")
         self.user.set_id(uuid.uuid4())
 
